process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0'
process.env.SUPPRESS_NO_CONFIG_WARNING = true

const cloneDeep = require('lodash/cloneDeep')
const httpMocks = require('node-mocks-http')
const Model = require('./../helpers/Model')
const fixtures = require('./../fixtures/fixtures')

jest.mock('pubsweet-component-mail-service', () => ({
  setupRevokeInvitationEmail: jest.fn(),
}))

const deletePath = '../../routes/collectionsInvitations/delete'

describe('Delete Collections Invitations route handler', () => {
  let testFixtures = {}
  let models
  beforeEach(() => {
    testFixtures = cloneDeep(fixtures)
    models = Model.build(testFixtures)
  })
  it('should return an error when the collection does not exist', async () => {
    const { editorInChief } = testFixtures.users
    const req = httpMocks.createRequest()
    req.params.collectionId = 'invalid-id'
    req.user = editorInChief.id
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)
    expect(res.statusCode).toBe(404)
    const data = JSON.parse(res._getData())
    expect(data.error).toEqual('collection not found')
  })
  it('should return an error when the invitation does not exist', async () => {
    const { editorInChief } = testFixtures.users
    const { collection } = testFixtures.collections
    const req = httpMocks.createRequest()
    req.params.collectionId = collection.id
    req.params.invitationId = 'invalid-id'
    req.user = editorInChief.id
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)
    expect(res.statusCode).toBe(404)
    const data = JSON.parse(res._getData())
    expect(data.error).toEqual('Invitation invalid-id not found')
  })
  it('should return success when the collection and invitation exist', async () => {
    const { editorInChief } = testFixtures.users
    const { collection } = testFixtures.collections
    const req = httpMocks.createRequest()
    req.params.collectionId = collection.id
    req.params.invitationId = collection.invitations[0].id
    req.user = editorInChief.id
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)
    expect(res.statusCode).toBe(200)
  })
})
