import { th } from '@pubsweet/ui'
import styled, { css } from 'styled-components'

const defaultText = css`
  color: ${th('colorText')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`
const Root = styled.div`
  display: flex;
  flex-direction: row;
  margin: auto;
`

const Title = styled.div`
  ${defaultText};
  font-size: ${th('fontSizeBase')};
  color: ${th('colorPrimary')};
  text-align: left;
  p {
    margin: 0;
  }
`

const Container = styled.div`
  flex: ${({ flex }) => flex || 1};
  padding: 0 ${th('subGridUnit')};
`

const SideBar = styled.div`
  flex: ${({ flex }) => flex || 1};
  background-color: ${th('colorBackground')};
  padding: 0 ${th('subGridUnit')};
`

const Header = styled.div`
  align-items: center;
  display: flex;
  flex-direction: row;
  margin-bottom: ${th('subGridUnit')};
  flex-wrap: wrap;
`

const BreadCrumbs = styled.div`
  & span {
    color: ${th('colorPrimary')};
    cursor: pointer;
    font-size: ${th('fontSizeBase')};
    text-align: left;
    
    &:after {
      content: '>';
      padding: 0 calc(${th('subGridUnit')}*2);
    }

    &:last-child {
      font-size: ${th('fontSizeBase')};
      font-weight: bold;
      margin-right: ${th('subGridUnit')};
      &:after {
        display: none;
    }
  }
`
const ManuscriptId = styled.div`
  ${defaultText};
  color: ${th('colorPrimary')};
  font-size: ${th('fontSizeBase')};
  margin-right: ${th('subGridUnit')};
  text-align: left;
  text-transform: uppercase;
  white-space: nowrap;
`

const LeftDetails = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  flex: ${({ flex }) => flex || 1};
`

const RightDetails = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
  align-items: center;
  flex: ${({ flex }) => flex || 1};
`

const StatusLabel = styled.div`
  border: ${th('borderDefault')};
  ${defaultText};
  font-weight: bold;
  padding: 0 0.5em;
  text-align: left;
  text-transform: capitalize;
  line-height: 1.5;
  color: ${th('colorPrimary')};
`

const DateField = styled.span`
  ${defaultText};
  margin: 0 ${th('subGridUnit')};
  text-align: left;
`
const Row = styled.div`
  display: flex;
  flex-direction: row;
  align-items: center;
  width: 100%;
  box-sizing: border-box;
  flex-wrap: wrap;
`

const ManuscriptType = styled.div`
  ${defaultText};
  padding: ${th('subGridUnit')};
  margin-left: calc(${th('subGridUnit')}*2);
  text-align: right;
  text-transform: capitalize;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
`

const ManuscriptHeader = styled.div`
  border-bottom: ${th('borderDefault')};
  padding-bottom: calc(${th('subGridUnit')}*2);
`

export {
  Root,
  BreadCrumbs,
  Header,
  Title,
  ManuscriptId,
  ManuscriptType,
  Container,
  SideBar,
  LeftDetails,
  RightDetails,
  StatusLabel,
  DateField,
  Row,
  ManuscriptHeader,
}
