const get = require('lodash/get')
const helpers = require('../../helpers/helpers')
const collectionHelper = require('../../helpers/Collection')
const teamHelper = require('../../helpers/Team')
const userHelper = require('../../helpers/User')

module.exports = models => async (req, res) => {
  const { email, role, isSubmitting, isCorresponding } = req.body

  if (
    !helpers.checkForUndefinedParams(email, role, isSubmitting, isCorresponding)
  )
    return res.status(400).json({ error: 'Missing parameters.' })

  const collectionId = get(req, 'params.collectionId')
  let collection
  try {
    collection = await models.Collection.find(collectionId)
  } catch (e) {
    const notFoundError = await helpers.handleNotFoundError(e, 'collection')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
  const url = `${req.protocol}://${req.get('host')}`

  try {
    let user = await models.User.findByEmail(email)

    if (role === 'author') {
      await teamHelper.setupManuscriptTeam(models, user, collectionId, role)
      // get updated user from DB
      user = await models.User.find(user.id)
      if (collection.authors !== undefined) {
        const match = collection.authors.find(
          author => author.userId === user.id,
        )
        if (match) {
          return res.status(400).json({
            error: `User ${user.email} is already an author`,
          })
        }
      }
      return await collectionHelper.addAuthor(
        collection,
        user,
        res,
        url,
        isSubmitting,
        isCorresponding,
      )
    }
    return res.status(400).json({
      error: `${role} is not defined`,
    })
  } catch (e) {
    if (role !== 'author') {
      return res.status(400).json({
        error: `${role} is not defined`,
      })
    }
    if (e.name === 'NotFoundError') {
      const newUser = await userHelper.setupNewUser(
        req.body,
        url,
        res,
        email,
        role,
        models.User,
        'invite-author',
      )
      if (newUser.error !== undefined) {
        return res.status(newUser.status).json({
          error: newUser.message,
        })
      }
      await teamHelper.setupManuscriptTeam(models, newUser, collectionId, role)
      return collectionHelper.addAuthor(
        collection,
        newUser,
        res,
        url,
        isSubmitting,
        isCorresponding,
      )
    }
    return res.status(e.status).json({
      error: 'Something went wrong',
    })
  }
}
